==> commerce_stripe_payment_request_button-8.x-1.5.tar.gz: commerce_stripe_payment_request_button/src/Controller/PaymentRequestButtonShipping.php <==
<?php

namespace Drupal\commerce_stripe_payment_request_button\Controller;

use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\commerce_price\Calculator;
use Drupal\commerce_price\Price;
use Drupal\commerce_shipping\Entity\Shipment;
use Drupal\commerce_shipping\ShipmentItem;
use Drupal\Component\Serialization\Json;
use Drupal\physical\Weight;
use Drupal\physical\WeightUnit;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

class PaymentRequestButtonShipping {

  public function handleShipping(Request $request) {

    // Transform JSON values to array
    $values = Json::decode($request->getContent());
    $shipping_info = $values["shippingAddress"];
    $order_id = $values["order_id"];

    $carts = \Drupal::getContainer()
      ->get('commerce_cart.cart_provider')
      ->getCarts();
    $active_cart = array_filter($carts, function (OrderInterface $cart) use ($order_id) {
      return $cart->id() == $order_id;
    });
    $order = reset($active_cart);


    if ($order->hasItems()) {
      // Check if we have some shipments made from before and delete them
      if ($order->get('shipments')->count() != 0) {
        unset($order->shipments);
        // TODO need to delete it from system
      }
      if ($order->get('shipments')->count() == 0) {
        $first_shipment = Shipment::create([
          'type' => 'default',
          'order_id' => $order_id,
          'title' => 'Shipment',
          'state' => 'ready',
        ]);

        // Loop through order items and add them to shipment
        foreach ($order->getItems() as $order_item) {
          $quantity = $order_item->getQuantity();
          $purchased_entity = $order_item->getPurchasedEntity();

          if ($purchased_entity->get('weight')->isEmpty()) {
            $weight = new Weight(1, WeightUnit::GRAM);
          }
          else {
            $weight_item = $purchased_entity->get('weight')->first();
            $weight = $weight_item->toMeasurement();
          }

          $shipment_item = new ShipmentItem([
            'order_item_id' => $order_item->id(),
            'title' => $purchased_entity->label(),
            'quantity' => $quantity,
            'weight' => $weight->multiply($quantity),
            'declared_value' => $order_item->getTotalPrice(),
          ]);
          $first_shipment->addItem($shipment_item);
        }

        // Find rate, we use the first one, pretending there is only one we want to use, fixed rate for order
        $shipping_method_storage = \Drupal::entityTypeManager()->getStorage('commerce_shipping_method');
        $shipping_methods = $shipping_method_storage->loadMultipleForShipment($first_shipment);
        $selected_shipping_method = reset($shipping_methods);
        $first_shipment->setShippingMethod($selected_shipping_method);

        $shipping_method_plugin = $selected_shipping_method->getPlugin();
        $shipping_rates = $shipping_method_plugin->calculateRates($first_shipment);
        $shipping_rate =  reset($shipping_rates);
        $selected_shipping_method_amount = $shipping_rate->getAmount();
        $first_shipment->setAmount($selected_shipping_method_amount);
      }

      //TODO dont repeat making new profile if there is already one assigned
      // make some kind of checker if profile exists in system

      // We only get the full name from Apple/Google pay, so we need to "guess" the given
      // name and the family name.
      $names = explode(' ', $shipping_info['recipient']);
      $given_name = array_shift($names);
      $family_name = implode(' ', $names);

      $profile = $this->buildCustomerProfile($order);
      $profile->address->given_name = $given_name;
      $profile->address->family_name = $family_name;

      $profile->address->given_name = $given_name;
      $profile->address->family_name = $family_name;
      $profile->address->country_code = $shipping_info['country'];
      $profile->address->locality = $shipping_info['city'];
      $profile->address->administrative_area = $shipping_info['dependentLocality'];
      $profile->address->postal_code = $shipping_info['postalCode'];
      $profile->address->address_line1 = $shipping_info["addressLine"][0];
      $profile->address->address_line2 = isset($shipping_info["addressLine"][1])?:"";
      $profile->save();

      $first_shipment->setShippingProfile($profile);
      $first_shipment->save();
      $order->set('shipments', $first_shipment);
      $order->save();
    }

    //TODO List all available shipping methods and when one is choosen, apply it later in order
    $response['shippingOptions'] = [
      [
        'id' => $selected_shipping_method->id(),
        'label' => $selected_shipping_method->getName(),
        'detail' => $shipping_rate->getService()->getLabel(),
        'amount' => $this->toMinorUnits($selected_shipping_method_amount),
      ],
    ];

    return new JsonResponse($response);
  }


  protected function buildCustomerProfile(OrderInterface $order) {
    return \Drupal::entityTypeManager()->getStorage('profile')->create([
      'uid' => $order->getCustomerId(),
      'type' => 'customer',
    ]);
  }

  /**
   * Converts the given amount to its minor units.
   *
   * For example, 9.99 USD becomes 999.
   *
   * @param \Drupal\commerce_price\Price $amount
   *   The amount.
   *
   * @return int
   *   The amount in minor units, as an integer.
   */
  protected function toMinorUnits(Price $amount) {
    $currency_storage = \Drupal::entityTypeManager()->getStorage('commerce_currency');
    $currency = $currency_storage->load($amount->getCurrencyCode());
    $fraction_digits = $currency->getFractionDigits();
    $number = $amount->getNumber();
    if ($fraction_digits > 0) {
      $number = Calculator::multiply($number, pow(10, $fraction_digits));
    }

    return intval(round($number, 0));
  }
}

==> commerce_stripe_payment_request_button-8.x-1.6.tar.gz: commerce_stripe_payment_request_button/src/Controller/PaymentRequestButtonShipping.php <==
<?php

namespace Drupal\commerce_stripe_payment_request_button\Controller;

use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\commerce_price\Calculator;
use Drupal\commerce_price\Price;
use Drupal\commerce_shipping\Entity\Shipment;
use Drupal\commerce_shipping\ShipmentItem;
use Drupal\Component\Serialization\Json;
use Drupal\physical\Weight;
use Drupal\physical\WeightUnit;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

class PaymentRequestButtonShipping {

  public function handleShipping(Request $request) {

    // Transform JSON values to array
    $values = Json::decode($request->getContent());
    $order_id = $values["order_id"];

    $carts = \Drupal::getContainer()
      ->get('commerce_cart.cart_provider')
      ->getCarts();
    $active_cart = array_filter($carts, function (OrderInterface $cart) use ($order_id) {
      return $cart->id() == $order_id;
    });
    $order = reset($active_cart);

    if ($order->hasItems()) {
      // Check if we have some shipments made from before and delete them
      if ($order->get('shipments')->count() != 0) {
        // Delete shipment made on previous selection
        $order->get('shipments')->first()->entity->delete();
        unset($order->shipments);
      }
      if ($order->get('shipments')->count() == 0) {
        $first_shipment = Shipment::create([
          'type' => 'default',
          'order_id' => $order_id,
          'title' => 'Shipment',
          'state' => 'ready',
        ]);

        // Find rate, we use the first one, pretending there is only one we want to use, fixed rate for order
        $shipping_method_storage = \Drupal::entityTypeManager()->getStorage('commerce_shipping_method');
        $shipping_methods = $shipping_method_storage->loadMultipleForShipment($first_shipment);

        // Loop through shipping methods and add them to array so it can be sent as Response to Stripe
        foreach ($shipping_methods as $shipping_method) {
          $first_shipment->setShippingMethod($shipping_method);
          $shipping_method_plugin = $shipping_method->getPlugin();
          $shipping_rates = $shipping_method_plugin->calculateRates($first_shipment);
          $shipping_rate =  reset($shipping_rates);
          $shipping_method_amount = $shipping_rate->getAmount();
          $first_shipment->setAmount($shipping_method_amount);
          $response_shipping_methods[] = [
            'id' => $shipping_method->id(),
            'label' => $shipping_method->getName(),
            'detail' => $shipping_rate->getService()->getLabel(),
            'amount' => $this->toMinorUnits($shipping_method_amount),
          ];
        }
      }
    }

    $response['shippingOptions'] = $response_shipping_methods;
    return new JsonResponse($response);
  }

  /**
   * Converts the given amount to its minor units.
   *
   * For example, 9.99 USD becomes 999.
   *
   * @param \Drupal\commerce_price\Price $amount
   *   The amount.
   *
   * @return int
   *   The amount in minor units, as an integer.
   */
  protected function toMinorUnits(Price $amount) {
    $currency_storage = \Drupal::entityTypeManager()->getStorage('commerce_currency');
    $currency = $currency_storage->load($amount->getCurrencyCode());
    $fraction_digits = $currency->getFractionDigits();
    $number = $amount->getNumber();
    if ($fraction_digits > 0) {
      $number = Calculator::multiply($number, pow(10, $fraction_digits));
    }

    return intval(round($number, 0));
  }
}
